#!/bin/zsh

# Check if the script is run as root
if [[ $EUID -eq 0 ]]; then
    echo "Run this script as a normal user, not as root."
    exit 1
fi

# Prepare Toolchain
echo "[DSMOSS] Prepare Toolchain..."
xcode-select --install
echo Install toolchain, then press ENTER.

# Prepare Homebrew
echo "[DSMOSS] Prepare Homebrew..."
/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)"
cp ~/.zprofile ~/.zprofile-pretapped
echo 'eval $(/opt/homebrew/bin/brew shellenv)' > ~/.zprofile
eval $(/opt/homebrew/bin/brew shellenv)

# Homebrew
echo "[DSMOSS] Install homebrew stuffs..."
brew install mas node python3 potrace telnet imagemagick wget golang gradle c2048
brew install ffmpeg yt-dlp
brew install --cask ollama darktable arc vscodium vlc protonvpn upscayl android-platform-tools libreoffice krita
brew install --cask inkscape
brew tap localsend/localsend
brew install localsend
brew install --cask nvidia-geforce-now roblox
brew install git-credential-manager
brew install --cask twingate

# NPM global
echo "[DSMOSS] Install NPM Global stuffs..."
sudo npm install -g cordova

# Mac App Store (MAS cli)
echo "[DSMOSS] Install Mac App Store stuffs..."
mas install 425424353 937984704 # The Unarchiver, Amphetamine.

# Install DOOM shareware
echo "[DSMOSS] [CHOCOD] Install DOOM Shareware..."
brew install chocolate-doom
cd ~/
wget http://www.doomworld.com/3ddownloads/ports/shareware_doom_iwad.zip
unzip shareware_doom_iwad.zip
rm shareware_doom_iwad.zip

# Make code folder
echo "[DSMOSS] Make code folder..."
mkdir ~/Code
cd ~/Code

# Install Video Editor...
echo "[DSMOSS] Install Video Editor..."
brew install --cask kdenlive

# Minecraft get!
echo "[DSMOSS] Minecraft get"
brew install microsoft-openjdk@21
echo 'export PATH="/usr/local/opt/openjdk@21/bin:$PATH"' >> ~/.zshrc
wget https://github.com/HMCL-dev/HMCL/releases/download/v3.5.9.259/HMCL-3.5.9.259.sh -O ~/Minecraft.sh
chmod +x ~/Minecraft.sh

# Create SSH helpers...
echo "[DSMOSS] Create SSH helpers..."
echo 'ssh root@192.168.50.144' > ~/ssh-to-felix.sh
echo 'ssh sparky@192.168.50.238' > ~/ssh-to-optishmex.sh
chmod +x ~/ssh-to-felix.sh ~/ssh-to-optishmex.sh

# Add extra net tools...
echo "[DSMOSS] Install more networking tools..."
brew install cloudflared miniupnpc
brew install --cask cyberduck

echo "[DSMOSS] Run the more common settings script..."
chmod +x "more-common-settings.sh"
./more-common-settings.sh

# Install Parsec
echo "[DSMOSS] Install Parsec..."
brew install --cask parsec